containertools.replace_n_edge_elements_in_container_with_big_endian_rests
=========================================================================

.. autofunction:: abjad.tools.containertools.replace_n_edge_elements_in_container_with_big_endian_rests.replace_n_edge_elements_in_container_with_big_endian_rests
